SET ECHO OFF
--DESCRIPTION
--Analyze and compute statistics for all tables
--owned by the user.

--Turn SERVEROUTPUT on so that we see output from the 
--PL/SQL block that we are going to execute.
SET SERVEROUTPUT ON

--The following PL/SQL block will build up and execute
--an ANALYZE TABLE command for each table. The DBMS_SQL
--package is used for this purpose.
DECLARE
  ddl_cursor_id   INTEGER;   
  analyze_command VARCHAR2(80);
  ignore_for_ddl  INTEGER; 
BEGIN
  --Allocate a cursor to use when executing DDL commands.
  ddl_cursor_id := DBMS_SQL.OPEN_CURSOR;

  --Execute an ANALYZE command for each table.
  FOR my_table in (
    SELECT table_name 
      FROM user_tables) LOOP

    --Create the command to analyze this table.
    analyze_command := 'ANALYZE TABLE ' 
                       || my_table.table_name
                       || ' COMPUTE STATISTICS';

    --Display the statement to be executed.
    DBMS_OUTPUT.PUT_LINE(analyze_command);

    --Parse & execute this ANALYZE command.
    DBMS_SQL.PARSE (ddl_cursor_id, analyze_command, DBMS_SQL.NATIVE);

    ignore_for_ddl := DBMS_SQL.EXECUTE (ddl_cursor_id);
  END LOOP;  

  --Deallocate the cursor.
  DBMS_SQL.CLOSE_CURSOR(ddl_cursor_id);
END;
/


