--DESCRIPTION
--This script information about security on a table.
--
--USAGE
--        @SHOW_SECURITY [owner.]table_name
--  
SET ECHO OFF 
SET VERIFY OFF
SET FEEDBACK OFF
SET PAGESIZE 9999
SET HEADING OFF
 
--Disect the input argument, and get the owner name and
--table name into two seperate substitution variables.
--The owner name defaults to the current user.
SET TERMOUT OFF
DEFINE s_owner_name = ' '
DEFINE s_synonym_name = ' '
COLUMN owner_name NOPRINT NEW_VALUE s_owner_name
COLUMN table_name NOPRINT NEW_VALUE s_table_name
SELECT
  DECODE(INSTR('&&1','.'),
         0,USER,  /*Default to current user.*/
         UPPER(SUBSTR('&&1',1,INSTR('&&1','.')-1))) owner_name,
  DECODE(INSTR('&&1','.'),
         0,UPPER('&&1'),  /*Only the table name was passed in.*/
         UPPER(SUBSTR('&&1',INSTR('&&1','.')+1))) table_name
  FROM dual;
SET TERMOUT ON

COLUMN grantee NOPRINT NEW_VALUE s_grantee
BREAK ON grantee SKIP PAGE
TTITLE LEFT 'PRIVILEGES GRANTED TO ' s_grantee -
       ' ON ' s_owner_name '.' s_table_name

--Execute a query to show privileges granted at the table level.
SELECT grantee, 
       '     ' || privilege || 
       DECODE(grantable, 'YES', ' with grant option', '') privilege
  FROM all_tab_privs
 WHERE table_schema = '&&s_owner_name'
   AND table_name = '&&s_table_name'
UNION
SELECT grantee,
       '     ' || privilege || ' of column ' || column_name 
       || DECODE(grantable, 'YES', ' with grant option', '') privilege
  FROM all_col_privs
 WHERE table_schema = '&&s_owner_name'
   AND table_name = '&&s_table_name'
ORDER BY grantee, privilege;
 
--Reset everything back to its default.
CLEAR COLUMNS
CLEAR BREAK
UNDEFINE s_owner_name
UNDEFINE s_table_name
SET VERIFY ON
SET FEEDBACK ON
SET HEADING ON
SET PAGESIZE 24


