--DESCRIPTION
--Print one of three user security reports

SET FEEDBACK OFF
SET PAGESIZE 20
SET LINESIZE 77
SET HEADING ON

--Ask the user what report to print
PROMPT 
PROMPT 1 - List users
PROMPT 2 - List users and table privileges
PROMPT 3 - List users and system privileges
PROMPT
ACCEPT s_report_choice PROMPT 'Enter your choice (1,2,3) >'

--Specify formats for all possible report columns.
COLUMN username FORMAT A12 HEADING 'User'
COLUMN privilege FORMAT A20 HEADING 'Privilege'
COLUMN owner FORMAT A12 HEADING 'Table Owner'
COLUMN table_name FORMAT A30 HEADING 'Table Name'
COLUMN error_message FORMAT A40 HEADING 'Error Message'

--Setup the page title. First we have to get the contents of 
--b_report_type into a substition variable.
set termout off
COLUMN b_report_type FORMAT A30 NOPRINT NEW_VALUE s_report_type
SELECT DECODE ('&&s_report_choice', 
               '1','User List',
               '2','User Table Privileges',
               '3','User System Privileges',
               'Invalid Choice') b_report_type
  FROM dual;
set termout on

TTITLE LEFT s_report_type RIGHT 'Page ' FORMAT 999 SQL.PNO SKIP 2

--Generate the query for the report requested by the user.
--Spool that query to a file.
SET TERMOUT OFF
SET PAGESIZE 0
SET HEADING OFF
SET VERIFY OFF
SET FEEDBACK OFF
COLUMN next_query FORMAT A60
SPOOL user_security_choice.sql

--This query will be successful if the user choose 1
SELECT 'SELECT username ' || CHR(10) ||
       '  FROM dba_users ' || CHR(10) ||
       'ORDER BY username;' || CHR(10) next_query
  FROM dual
 WHERE '&&s_report_choice' = '1';

--This query will be successful if the user choose 2
SELECT 'SELECT username, privilege, owner, table_name' || CHR(10) ||
       '  FROM dba_users, dba_tab_privs' || CHR(10) ||
       ' WHERE username = grantee' || CHR(10) ||
       'ORDER BY username, owner, table_name, privilege;'
  FROM dual
 WHERE '&&s_report_choice' = '2';

SELECT 'SELECT username, privilege' || CHR(10) ||
       '  FROM dba_users, dba_sys_privs' || CHR(10) ||
       ' WHERE username = grantee' || CHR(10) ||
       'ORDER BY username, privilege;' 
  FROM dual
 WHERE '&&s_report_choice' = '3';

SELECT 'PROMPT You must choose either 1, 2, or 3'
  FROM dual
 WHERE '&&s_report_choice' NOT IN ('1','2','3')
    OR '&&s_report_choice' IS NULL;

SPOOL OFF
SET TERMOUT ON
SET PAGESIZE 20
SET HEADING ON
SET VERIFY ON

--Now execute the query that we just spooled.
@user_security_choice

--Reset all the settings back to their defaults
SET FEEDBACK ON
CLEAR COLUMNS
TTITLE OFF
